# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/organizationmanager/v1/saml/certificate_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/organizationmanager/v1/saml/certificate_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.organizationmanager.v1.saml import certificate_pb2 as yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_certificate__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nByandex/cloud/organizationmanager/v1/saml/certificate_service.proto\x12(yandex.cloud.organizationmanager.v1.saml\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a:yandex/cloud/organizationmanager/v1/saml/certificate.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"9\n\x15GetCertificateRequest\x12 \n\x0e\x63\x65rtificate_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"\x99\x01\n\x17ListCertificatesRequest\x12#\n\rfederation_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"\x80\x01\n\x18ListCertificatesResponse\x12K\n\x0c\x63\x65rtificates\x18\x01 \x03(\x0b\x32\x35.yandex.cloud.organizationmanager.v1.saml.Certificate\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xa9\x01\n\x18\x43reateCertificateRequest\x12\x1f\n\rfederation_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x31\n\x04name\x18\x02 \x01(\tB#\xf2\xc7\x31\x1f[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x19\n\x04\x64\x61ta\x18\x04 \x01(\tB\x0b\x8a\xc8\x31\x07<=32000\"3\n\x19\x43reateCertificateMetadata\x12\x16\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\t\"\xdc\x01\n\x18UpdateCertificateRequest\x12 \n\x0e\x63\x65rtificate_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x19\n\x04\x64\x61ta\x18\x05 \x01(\tB\x0b\x8a\xc8\x31\x07<=32000\"3\n\x19UpdateCertificateMetadata\x12\x16\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\t\"<\n\x18\x44\x65leteCertificateRequest\x12 \n\x0e\x63\x65rtificate_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"3\n\x19\x44\x65leteCertificateMetadata\x12\x16\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\t\"\x83\x01\n ListCertificateOperationsRequest\x12 \n\x0e\x63\x65rtificate_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\"s\n!ListCertificateOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xc1\n\n\x12\x43\x65rtificateService\x12\xc2\x01\n\x03Get\x12?.yandex.cloud.organizationmanager.v1.saml.GetCertificateRequest\x1a\x35.yandex.cloud.organizationmanager.v1.saml.Certificate\"C\x82\xd3\xe4\x93\x02=\x12;/organization-manager/v1/saml/certificates/{certificate_id}\x12\xc1\x01\n\x04List\x12\x41.yandex.cloud.organizationmanager.v1.saml.ListCertificatesRequest\x1a\x42.yandex.cloud.organizationmanager.v1.saml.ListCertificatesResponse\"2\x82\xd3\xe4\x93\x02,\x12*/organization-manager/v1/saml/certificates\x12\xd2\x01\n\x06\x43reate\x12\x42.yandex.cloud.organizationmanager.v1.saml.CreateCertificateRequest\x1a!.yandex.cloud.operation.Operation\"a\xb2\xd2*(\n\x19\x43reateCertificateMetadata\x12\x0b\x43\x65rtificate\x82\xd3\xe4\x93\x02/\"*/organization-manager/v1/saml/certificates:\x01*\x12\xe3\x01\n\x06Update\x12\x42.yandex.cloud.organizationmanager.v1.saml.UpdateCertificateRequest\x1a!.yandex.cloud.operation.Operation\"r\xb2\xd2*(\n\x19UpdateCertificateMetadata\x12\x0b\x43\x65rtificate\x82\xd3\xe4\x93\x02@2;/organization-manager/v1/saml/certificates/{certificate_id}:\x01*\x12\xea\x01\n\x06\x44\x65lete\x12\x42.yandex.cloud.organizationmanager.v1.saml.DeleteCertificateRequest\x1a!.yandex.cloud.operation.Operation\"y\xb2\xd2*2\n\x19\x44\x65leteCertificateMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02=*;/organization-manager/v1/saml/certificates/{certificate_id}\x12\xf9\x01\n\x0eListOperations\x12J.yandex.cloud.organizationmanager.v1.saml.ListCertificateOperationsRequest\x1aK.yandex.cloud.organizationmanager.v1.saml.ListCertificateOperationsResponse\"N\x82\xd3\xe4\x93\x02H\x12\x46/organization-manager/v1/saml/certificates/{certificate_id}/operationsB\x81\x01\n,yandex.cloud.api.organizationmanager.v1.samlZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/saml;samlb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.organizationmanager.v1.saml.certificate_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n,yandex.cloud.api.organizationmanager.v1.samlZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/saml;saml'
  _globals['_GETCERTIFICATEREQUEST'].fields_by_name['certificate_id']._loaded_options = None
  _globals['_GETCERTIFICATEREQUEST'].fields_by_name['certificate_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_LISTCERTIFICATESREQUEST'].fields_by_name['federation_id']._loaded_options = None
  _globals['_LISTCERTIFICATESREQUEST'].fields_by_name['federation_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCERTIFICATESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCERTIFICATESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTCERTIFICATESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCERTIFICATESREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _globals['_LISTCERTIFICATESREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTCERTIFICATESREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_CREATECERTIFICATEREQUEST'].fields_by_name['federation_id']._loaded_options = None
  _globals['_CREATECERTIFICATEREQUEST'].fields_by_name['federation_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_CREATECERTIFICATEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATECERTIFICATEREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\037[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _globals['_CREATECERTIFICATEREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATECERTIFICATEREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CREATECERTIFICATEREQUEST'].fields_by_name['data']._loaded_options = None
  _globals['_CREATECERTIFICATEREQUEST'].fields_by_name['data']._serialized_options = b'\212\3101\007<=32000'
  _globals['_UPDATECERTIFICATEREQUEST'].fields_by_name['certificate_id']._loaded_options = None
  _globals['_UPDATECERTIFICATEREQUEST'].fields_by_name['certificate_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_UPDATECERTIFICATEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATECERTIFICATEREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _globals['_UPDATECERTIFICATEREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATECERTIFICATEREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATECERTIFICATEREQUEST'].fields_by_name['data']._loaded_options = None
  _globals['_UPDATECERTIFICATEREQUEST'].fields_by_name['data']._serialized_options = b'\212\3101\007<=32000'
  _globals['_DELETECERTIFICATEREQUEST'].fields_by_name['certificate_id']._loaded_options = None
  _globals['_DELETECERTIFICATEREQUEST'].fields_by_name['certificate_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_LISTCERTIFICATEOPERATIONSREQUEST'].fields_by_name['certificate_id']._loaded_options = None
  _globals['_LISTCERTIFICATEOPERATIONSREQUEST'].fields_by_name['certificate_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_LISTCERTIFICATEOPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCERTIFICATEOPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTCERTIFICATEOPERATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCERTIFICATEOPERATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _globals['_CERTIFICATESERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_CERTIFICATESERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002=\022;/organization-manager/v1/saml/certificates/{certificate_id}'
  _globals['_CERTIFICATESERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_CERTIFICATESERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002,\022*/organization-manager/v1/saml/certificates'
  _globals['_CERTIFICATESERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_CERTIFICATESERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*(\n\031CreateCertificateMetadata\022\013Certificate\202\323\344\223\002/\"*/organization-manager/v1/saml/certificates:\001*'
  _globals['_CERTIFICATESERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_CERTIFICATESERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*(\n\031UpdateCertificateMetadata\022\013Certificate\202\323\344\223\002@2;/organization-manager/v1/saml/certificates/{certificate_id}:\001*'
  _globals['_CERTIFICATESERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_CERTIFICATESERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*2\n\031DeleteCertificateMetadata\022\025google.protobuf.Empty\202\323\344\223\002=*;/organization-manager/v1/saml/certificates/{certificate_id}'
  _globals['_CERTIFICATESERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_CERTIFICATESERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002H\022F/organization-manager/v1/saml/certificates/{certificate_id}/operations'
  _globals['_GETCERTIFICATEREQUEST']._serialized_start=341
  _globals['_GETCERTIFICATEREQUEST']._serialized_end=398
  _globals['_LISTCERTIFICATESREQUEST']._serialized_start=401
  _globals['_LISTCERTIFICATESREQUEST']._serialized_end=554
  _globals['_LISTCERTIFICATESRESPONSE']._serialized_start=557
  _globals['_LISTCERTIFICATESRESPONSE']._serialized_end=685
  _globals['_CREATECERTIFICATEREQUEST']._serialized_start=688
  _globals['_CREATECERTIFICATEREQUEST']._serialized_end=857
  _globals['_CREATECERTIFICATEMETADATA']._serialized_start=859
  _globals['_CREATECERTIFICATEMETADATA']._serialized_end=910
  _globals['_UPDATECERTIFICATEREQUEST']._serialized_start=913
  _globals['_UPDATECERTIFICATEREQUEST']._serialized_end=1133
  _globals['_UPDATECERTIFICATEMETADATA']._serialized_start=1135
  _globals['_UPDATECERTIFICATEMETADATA']._serialized_end=1186
  _globals['_DELETECERTIFICATEREQUEST']._serialized_start=1188
  _globals['_DELETECERTIFICATEREQUEST']._serialized_end=1248
  _globals['_DELETECERTIFICATEMETADATA']._serialized_start=1250
  _globals['_DELETECERTIFICATEMETADATA']._serialized_end=1301
  _globals['_LISTCERTIFICATEOPERATIONSREQUEST']._serialized_start=1304
  _globals['_LISTCERTIFICATEOPERATIONSREQUEST']._serialized_end=1435
  _globals['_LISTCERTIFICATEOPERATIONSRESPONSE']._serialized_start=1437
  _globals['_LISTCERTIFICATEOPERATIONSRESPONSE']._serialized_end=1552
  _globals['_CERTIFICATESERVICE']._serialized_start=1555
  _globals['_CERTIFICATESERVICE']._serialized_end=2900
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import yandex.cloud.compute.v1.instance_pb2
import yandex.cloud.compute.v1.instance_service_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ProductIDs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRODUCT_IDS_FIELD_NUMBER: builtins.int
    @property
    def product_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """License IDs that indicate which licenses are attached to resource.
        License IDs are used to calculate additional charges for the use of the virtual machine.
        """

    def __init__(
        self,
        *,
        product_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["product_ids", b"product_ids"]) -> None: ...

global___ProductIDs = ProductIDs

@typing.final
class BootDiskSpec(google.protobuf.message.Message):
    """Specification used to determine required product_ids
    You can specify product ids explicitly or use disk_id|image_id|snapshot_id to infer products ids from them.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISK_ID_FIELD_NUMBER: builtins.int
    IMAGE_ID_FIELD_NUMBER: builtins.int
    SNAPSHOT_ID_FIELD_NUMBER: builtins.int
    PRODUCT_IDS_FIELD_NUMBER: builtins.int
    disk_id: builtins.str
    """Disk ID."""
    image_id: builtins.str
    """Image ID."""
    snapshot_id: builtins.str
    """Snapshot ID."""
    @property
    def product_ids(self) -> global___ProductIDs:
        """Product IDs."""

    def __init__(
        self,
        *,
        disk_id: builtins.str = ...,
        image_id: builtins.str = ...,
        snapshot_id: builtins.str = ...,
        product_ids: global___ProductIDs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["boot_source", b"boot_source", "disk_id", b"disk_id", "image_id", b"image_id", "product_ids", b"product_ids", "snapshot_id", b"snapshot_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["boot_source", b"boot_source", "disk_id", b"disk_id", "image_id", b"image_id", "product_ids", b"product_ids", "snapshot_id", b"snapshot_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["boot_source", b"boot_source"]) -> typing.Literal["disk_id", "image_id", "snapshot_id", "product_ids"] | None: ...

global___BootDiskSpec = BootDiskSpec

@typing.final
class ReservedInstancePool(google.protobuf.message.Message):
    """A Reserved Instance Pool resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    ZONE_ID_FIELD_NUMBER: builtins.int
    CLOUD_ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    PLATFORM_ID_FIELD_NUMBER: builtins.int
    RESOURCES_SPEC_FIELD_NUMBER: builtins.int
    GPU_SETTINGS_FIELD_NUMBER: builtins.int
    PRODUCT_IDS_FIELD_NUMBER: builtins.int
    NETWORK_SETTINGS_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the pool."""
    zone_id: builtins.str
    """ID of the availability zone where the pool resides."""
    cloud_id: builtins.str
    """ID of the cloud that the pool belongs to."""
    folder_id: builtins.str
    """ID of the folder that the pool belongs to."""
    name: builtins.str
    """Name of the pool. 1-63 characters long."""
    description: builtins.str
    """Description of the pool. 0-256 characters long."""
    platform_id: builtins.str
    """ID of the hardware platform configuration for pool instances."""
    size: builtins.int
    """Desired size of the pool (number of slots for instances in this pool)."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs. Maximum of 64 per resource."""

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def resources_spec(self) -> yandex.cloud.compute.v1.instance_service_pb2.ResourcesSpec:
        """Computing resources of pool instances, such as the amount of memory and number of cores."""

    @property
    def gpu_settings(self) -> yandex.cloud.compute.v1.instance_pb2.GpuSettings:
        """GPU settings."""

    @property
    def product_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """License IDs that indicate which licenses are attached to resource.
        License IDs are used to calculate additional charges for the use of the virtual machine.
        """

    @property
    def network_settings(self) -> yandex.cloud.compute.v1.instance_pb2.NetworkSettings:
        """Network Settings."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        zone_id: builtins.str = ...,
        cloud_id: builtins.str = ...,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        platform_id: builtins.str = ...,
        resources_spec: yandex.cloud.compute.v1.instance_service_pb2.ResourcesSpec | None = ...,
        gpu_settings: yandex.cloud.compute.v1.instance_pb2.GpuSettings | None = ...,
        product_ids: collections.abc.Iterable[builtins.str] | None = ...,
        network_settings: yandex.cloud.compute.v1.instance_pb2.NetworkSettings | None = ...,
        size: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "gpu_settings", b"gpu_settings", "network_settings", b"network_settings", "resources_spec", b"resources_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cloud_id", b"cloud_id", "created_at", b"created_at", "description", b"description", "folder_id", b"folder_id", "gpu_settings", b"gpu_settings", "id", b"id", "labels", b"labels", "name", b"name", "network_settings", b"network_settings", "platform_id", b"platform_id", "product_ids", b"product_ids", "resources_spec", b"resources_spec", "size", b"size", "zone_id", b"zone_id"]) -> None: ...

global___ReservedInstancePool = ReservedInstancePool



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.apploadbalancer.v1.load_balancer_pb2
import yandex.cloud.apploadbalancer.v1.logging_pb2
import yandex.cloud.operation.operation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetLoadBalancerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOAD_BALANCER_ID_FIELD_NUMBER: builtins.int
    load_balancer_id: builtins.str
    """ID of the application load balancer to return.

    To get the application load balancer ID, make a [LoadBalancerService.List] request.
    """
    def __init__(
        self,
        *,
        load_balancer_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["load_balancer_id", b"load_balancer_id"]) -> None: ...

global___GetLoadBalancerRequest = GetLoadBalancerRequest

@typing.final
class ListLoadBalancersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list application load balancers in.

    To get the folder ID, make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `page_size`, the service returns a [ListLoadBalancersResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListLoadBalancersResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters application load balancers listed in the response.

    The expression must specify:
    1. The field name. Currently you can use filtering only on [LoadBalancer.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    Example of a filter: `name=my-load-balancer`.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListLoadBalancersRequest = ListLoadBalancersRequest

@typing.final
class ListLoadBalancersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOAD_BALANCERS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListLoadBalancersRequest.page_size], use `next_page_token` as the value
    for the [ListLoadBalancersRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def load_balancers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.apploadbalancer.v1.load_balancer_pb2.LoadBalancer]:
        """List of application load balancers in the specified folder."""

    def __init__(
        self,
        *,
        load_balancers: collections.abc.Iterable[yandex.cloud.apploadbalancer.v1.load_balancer_pb2.LoadBalancer] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["load_balancers", b"load_balancers", "next_page_token", b"next_page_token"]) -> None: ...

global___ListLoadBalancersResponse = ListLoadBalancersResponse

@typing.final
class DeleteLoadBalancerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOAD_BALANCER_ID_FIELD_NUMBER: builtins.int
    load_balancer_id: builtins.str
    """ID of the application load balancer to delete.

    To get the application load balancer ID, make a [LoadBalancerService.List] request.
    """
    def __init__(
        self,
        *,
        load_balancer_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["load_balancer_id", b"load_balancer_id"]) -> None: ...

global___DeleteLoadBalancerRequest = DeleteLoadBalancerRequest

@typing.final
class DeleteLoadBalancerMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOAD_BALANCER_ID_FIELD_NUMBER: builtins.int
    load_balancer_id: builtins.str
    """ID of the application load balancer that is being deleted."""
    def __init__(
        self,
        *,
        load_balancer_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["load_balancer_id", b"load_balancer_id"]) -> None: ...

global___DeleteLoadBalancerMetadata = DeleteLoadBalancerMetadata

@typing.final
class UpdateLoadBalancerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    LOAD_BALANCER_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LISTENER_SPECS_FIELD_NUMBER: builtins.int
    ALLOCATION_POLICY_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    AUTO_SCALE_POLICY_FIELD_NUMBER: builtins.int
    LOG_OPTIONS_FIELD_NUMBER: builtins.int
    load_balancer_id: builtins.str
    """ID of the application load balancer to update.

    To get the application load balancer ID, make a [LoadBalancerService.List] request.
    """
    name: builtins.str
    """New name for the application load balancer.
    The name must be unique within the folder.
    """
    description: builtins.str
    """New description of the application load balancer."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which attributes of the application load balancer should be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """New application load balancer labels as `key:value` pairs.
        For details about the concept, see [documentation](/docs/overview/concepts/services#labels).

        Existing set of labels is completely replaced by the provided set, so if you just want
        to add or remove a label:
        1. Get the current set of labels with a [LoadBalancerService.Get] request.
        2. Add or remove a label in this set.
        3. Send the new set in this field.
        """

    @property
    def listener_specs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ListenerSpec]:
        """New listeners for the application load balancer.

        For details about the concept,
        see [documentation](/docs/application-load-balancer/concepts/application-load-balancer#listener).

        Existing list of listeners is completely replaced by the specified list, so if you just want to add, update,
        or remove a listener, make a [LoadBalancerService.AddListener] request,
        a [LoadBalancerService.UpdateListener] request, or a [LoadBalancerService.RemoveListener] request.
        """

    @property
    def allocation_policy(self) -> yandex.cloud.apploadbalancer.v1.load_balancer_pb2.AllocationPolicy:
        """New locality settings of the application load balancer.

        For details about the concept,
        see [documentation](/docs/application-load-balancer/concepts/application-load-balancer#lb-location).

        Existing locality settings are completely replaced by the specified settings,
        so if you just want to add or remove an allocation policy:
        1. Get the current settings with a [LoadBalancerService.Get] request.
        2. Add or remove a policy in this set.
        3. Send the new set in this field.
        """

    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """ID's of new security groups attributed to the application load balancer.

        For details about the concept,
        see [documentation](/docs/application-load-balancer/concepts/application-load-balancer#security-groups).

        Existing list of security groups is completely replaced by the specified list,
        so if you just want to add or remove an allocation policy:
        1. Get the current set of security groups with a [LoadBalancerService.Get] request.
        2. Add or remove a group in this set.
        3. Send the new set in this field.
        """

    @property
    def auto_scale_policy(self) -> yandex.cloud.apploadbalancer.v1.load_balancer_pb2.AutoScalePolicy:
        """New scaling settings of the application load balancer.

        The scaling settings relate to a special internal instance group which facilitates the balancer's work.
        Instances in this group are called _resource units_. The group is scaled automatically based on incoming load
        and within limitations specified in these settings.

        For details about the concept,
        see [documentation](/docs/application-load-balancer/concepts/application-load-balancer#lcu-scaling).
        """

    @property
    def log_options(self) -> yandex.cloud.apploadbalancer.v1.logging_pb2.LogOptions:
        """Cloud logging settings of the application load balancer."""

    def __init__(
        self,
        *,
        load_balancer_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        listener_specs: collections.abc.Iterable[global___ListenerSpec] | None = ...,
        allocation_policy: yandex.cloud.apploadbalancer.v1.load_balancer_pb2.AllocationPolicy | None = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        auto_scale_policy: yandex.cloud.apploadbalancer.v1.load_balancer_pb2.AutoScalePolicy | None = ...,
        log_options: yandex.cloud.apploadbalancer.v1.logging_pb2.LogOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["allocation_policy", b"allocation_policy", "auto_scale_policy", b"auto_scale_policy", "log_options", b"log_options", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["allocation_policy", b"allocation_policy", "auto_scale_policy", b"auto_scale_policy", "description", b"description", "labels", b"labels", "listener_specs", b"listener_specs", "load_balancer_id", b"load_balancer_id", "log_options", b"log_options", "name", b"name", "security_group_ids", b"security_group_ids", "update_mask", b"update_mask"]) -> None: ...

global___UpdateLoadBalancerRequest = UpdateLoadBalancerRequest

@typing.final
class UpdateLoadBalancerMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOAD_BALANCER_ID_FIELD_NUMBER: builtins.int
    load_balancer_id: builtins.str
    """ID of the application load balancer that is being updated."""
    def __init__(
        self,
        *,
        load_balancer_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["load_balancer_id", b"load_balancer_id"]) -> None: ...

global___UpdateLoadBalancerMetadata = UpdateLoadBalancerMetadata

@typing.final
class CreateLoadBalancerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    REGION_ID_FIELD_NUMBER: builtins.int
    NETWORK_ID_FIELD_NUMBER: builtins.int
    LISTENER_SPECS_FIELD_NUMBER: builtins.int
    ALLOCATION_POLICY_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    AUTO_SCALE_POLICY_FIELD_NUMBER: builtins.int
    LOG_OPTIONS_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create an application load balancer in.

    To get the folder ID, make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    name: builtins.str
    """Name of the application load balancer.
    The name must be unique within the folder.
    """
    description: builtins.str
    """Description of the application load balancer."""
    region_id: builtins.str
    """ID of the region that the application load balancer is located at.

    The only supported value is `ru-central1`.
    """
    network_id: builtins.str
    """ID of the network that the application load balancer belongs to."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Application load balancer labels as `key:value` pairs.
        For details about the concept, see [documentation](/docs/overview/concepts/services#labels).
        """

    @property
    def listener_specs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ListenerSpec]:
        """Listeners that belong to the application load balancer.

        For details about the concept,
        see [documentation](/docs/application-load-balancer/concepts/application-load-balancer#listener).
        """

    @property
    def allocation_policy(self) -> yandex.cloud.apploadbalancer.v1.load_balancer_pb2.AllocationPolicy:
        """Locality settings of the application load balancer.

        For details about the concept,
        see [documentation](/docs/application-load-balancer/concepts/application-load-balancer#lb-location).
        """

    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """ID's of the security groups attributed to the application load balancer.

        For details about the concept,
        see [documentation](/docs/application-load-balancer/concepts/application-load-balancer#security-groups).
        """

    @property
    def auto_scale_policy(self) -> yandex.cloud.apploadbalancer.v1.load_balancer_pb2.AutoScalePolicy:
        """Scaling settings of the application load balancer.

        The scaling settings relate to a special internal instance group which facilitates the balancer's work.
        Instances in this group are called _resource units_. The group is scaled automatically based on incoming load
        and within limitations specified in these settings.

        For details about the concept,
        see [documentation](/docs/application-load-balancer/concepts/application-load-balancer#lcu-scaling).
        """

    @property
    def log_options(self) -> yandex.cloud.apploadbalancer.v1.logging_pb2.LogOptions:
        """Cloud logging settings of the application load balancer."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        region_id: builtins.str = ...,
        network_id: builtins.str = ...,
        listener_specs: collections.abc.Iterable[global___ListenerSpec] | None = ...,
        allocation_policy: yandex.cloud.apploadbalancer.v1.load_balancer_pb2.AllocationPolicy | None = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        auto_scale_policy: yandex.cloud.apploadbalancer.v1.load_balancer_pb2.AutoScalePolicy | None = ...,
        log_options: yandex.cloud.apploadbalancer.v1.logging_pb2.LogOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["allocation_policy", b"allocation_policy", "auto_scale_policy", b"auto_scale_policy", "log_options", b"log_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["allocation_policy", b"allocation_policy", "auto_scale_policy", b"auto_scale_policy", "description", b"description", "folder_id", b"folder_id", "labels", b"labels", "listener_specs", b"listener_specs", "log_options", b"log_options", "name", b"name", "network_id", b"network_id", "region_id", b"region_id", "security_group_ids", b"security_group_ids"]) -> None: ...

global___CreateLoadBalancerRequest = CreateLoadBalancerRequest

@typing.final
class CreateLoadBalancerMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOAD_BALANCER_ID_FIELD_NUMBER: builtins.int
    load_balancer_id: builtins.str
    """ID of the application load balancer that is being created."""
    def __init__(
        self,
        *,
        load_balancer_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["load_balancer_id", b"load_balancer_id"]) -> None: ...

global___CreateLoadBalancerMetadata = CreateLoadBalancerMetadata

@typing.final
class StartLoadBalancerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOAD_BALANCER_ID_FIELD_NUMBER: builtins.int
    load_balancer_id: builtins.str
    """ID of the application load balancer to start.

    The application load balancer must have a `STOPPED` status ([LoadBalancer.status]).

    To get the application load balancer ID, make a [LoadBalancerService.List] request.
    """
    def __init__(
        self,
        *,
        load_balancer_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["load_balancer_id", b"load_balancer_id"]) -> None: ...

global___StartLoadBalancerRequest = StartLoadBalancerRequest

@typing.final
class StartLoadBalancerMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOAD_BALANCER_ID_FIELD_NUMBER: builtins.int
    load_balancer_id: builtins.str
    """ID of the application load balancer that is being started."""
    def __init__(
        self,
        *,
        load_balancer_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["load_balancer_id", b"load_balancer_id"]) -> None: ...

global___StartLoadBalancerMetadata = StartLoadBalancerMetadata

@typing.final
class StopLoadBalancerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOAD_BALANCER_ID_FIELD_NUMBER: builtins.int
    load_balancer_id: builtins.str
    """ID of the application load balancer to stop.

    The application load balancer must have an `ACTIVE` status ([LoadBalancer.status]).

    To get the application load balancer ID, make a [LoadBalancerService.List] request.
    """
    def __init__(
        self,
        *,
        load_balancer_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["load_balancer_id", b"load_balancer_id"]) -> None: ...

global___StopLoadBalancerRequest = StopLoadBalancerRequest

@typing.final
class StopLoadBalancerMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOAD_BALANCER_ID_FIELD_NUMBER: builtins.int
    load_balancer_id: builtins.str
    """ID of the application load balancer that is being stopped."""
    def __init__(
        self,
        *,
        load_balancer_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["load_balancer_id", b"load_balancer_id"]) -> None: ...

global___StopLoadBalancerMetadata = StopLoadBalancerMetadata

@typing.final
class AddListenerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOAD_BALANCER_ID_FIELD_NUMBER: builtins.int
    LISTENER_SPEC_FIELD_NUMBER: builtins.int
    load_balancer_id: builtins.str
    """ID of the application load balancer to add a listener to."""
    @property
    def listener_spec(self) -> global___ListenerSpec:
        """Listener to add to the application load balancer."""

    def __init__(
        self,
        *,
        load_balancer_id: builtins.str = ...,
        listener_spec: global___ListenerSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["listener_spec", b"listener_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["listener_spec", b"listener_spec", "load_balancer_id", b"load_balancer_id"]) -> None: ...

global___AddListenerRequest = AddListenerRequest

@typing.final
class AddListenerMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOAD_BALANCER_ID_FIELD_NUMBER: builtins.int
    LISTENER_NAME_FIELD_NUMBER: builtins.int
    load_balancer_id: builtins.str
    """ID of the application load balancer that the listener is being added to."""
    listener_name: builtins.str
    """Name of the listener that is being added to the application load balancer."""
    def __init__(
        self,
        *,
        load_balancer_id: builtins.str = ...,
        listener_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["listener_name", b"listener_name", "load_balancer_id", b"load_balancer_id"]) -> None: ...

global___AddListenerMetadata = AddListenerMetadata

@typing.final
class RemoveListenerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOAD_BALANCER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    load_balancer_id: builtins.str
    """ID of the application load balancer to remove the listener from."""
    name: builtins.str
    """Name of the listener to remove from the application load balancer."""
    def __init__(
        self,
        *,
        load_balancer_id: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["load_balancer_id", b"load_balancer_id", "name", b"name"]) -> None: ...

global___RemoveListenerRequest = RemoveListenerRequest

@typing.final
class RemoveListenerMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOAD_BALANCER_ID_FIELD_NUMBER: builtins.int
    LISTENER_NAME_FIELD_NUMBER: builtins.int
    load_balancer_id: builtins.str
    """ID of the application load balancer that the listener is being removed from."""
    listener_name: builtins.str
    """Name of the listener that is being removed from the application load balancer."""
    def __init__(
        self,
        *,
        load_balancer_id: builtins.str = ...,
        listener_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["listener_name", b"listener_name", "load_balancer_id", b"load_balancer_id"]) -> None: ...

global___RemoveListenerMetadata = RemoveListenerMetadata

@typing.final
class UpdateListenerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOAD_BALANCER_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    LISTENER_SPEC_FIELD_NUMBER: builtins.int
    load_balancer_id: builtins.str
    """ID of the application load balancer to update the listener in."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which attributes of the listener should be updated."""

    @property
    def listener_spec(self) -> global___ListenerSpec:
        """New attributes of the listener."""

    def __init__(
        self,
        *,
        load_balancer_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        listener_spec: global___ListenerSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["listener_spec", b"listener_spec", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["listener_spec", b"listener_spec", "load_balancer_id", b"load_balancer_id", "update_mask", b"update_mask"]) -> None: ...

global___UpdateListenerRequest = UpdateListenerRequest

@typing.final
class UpdateListenerMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOAD_BALANCER_ID_FIELD_NUMBER: builtins.int
    LISTENER_NAME_FIELD_NUMBER: builtins.int
    load_balancer_id: builtins.str
    """ID of the application load balancer that the listener is being updated in."""
    listener_name: builtins.str
    """Name of the listener that is being updated."""
    def __init__(
        self,
        *,
        load_balancer_id: builtins.str = ...,
        listener_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["listener_name", b"listener_name", "load_balancer_id", b"load_balancer_id"]) -> None: ...

global___UpdateListenerMetadata = UpdateListenerMetadata

@typing.final
class AddressSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXTERNAL_IPV4_ADDRESS_SPEC_FIELD_NUMBER: builtins.int
    INTERNAL_IPV4_ADDRESS_SPEC_FIELD_NUMBER: builtins.int
    EXTERNAL_IPV6_ADDRESS_SPEC_FIELD_NUMBER: builtins.int
    @property
    def external_ipv4_address_spec(self) -> global___ExternalIpv4AddressSpec:
        """Public IPv4 endpoint address."""

    @property
    def internal_ipv4_address_spec(self) -> global___InternalIpv4AddressSpec:
        """Internal IPv4 endpoint address.

        To enable the use of listeners with internal addresses, [contact support](/docs/support/overview#response-time).
        """

    @property
    def external_ipv6_address_spec(self) -> global___ExternalIpv6AddressSpec:
        """Public IPv6 endpoint address."""

    def __init__(
        self,
        *,
        external_ipv4_address_spec: global___ExternalIpv4AddressSpec | None = ...,
        internal_ipv4_address_spec: global___InternalIpv4AddressSpec | None = ...,
        external_ipv6_address_spec: global___ExternalIpv6AddressSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["address_spec", b"address_spec", "external_ipv4_address_spec", b"external_ipv4_address_spec", "external_ipv6_address_spec", b"external_ipv6_address_spec", "internal_ipv4_address_spec", b"internal_ipv4_address_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["address_spec", b"address_spec", "external_ipv4_address_spec", b"external_ipv4_address_spec", "external_ipv6_address_spec", b"external_ipv6_address_spec", "internal_ipv4_address_spec", b"internal_ipv4_address_spec"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["address_spec", b"address_spec"]) -> typing.Literal["external_ipv4_address_spec", "internal_ipv4_address_spec", "external_ipv6_address_spec"] | None: ...

global___AddressSpec = AddressSpec

@typing.final
class ExternalIpv4AddressSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_FIELD_NUMBER: builtins.int
    address: builtins.str
    """IPv4 address."""
    def __init__(
        self,
        *,
        address: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["address", b"address"]) -> None: ...

global___ExternalIpv4AddressSpec = ExternalIpv4AddressSpec

@typing.final
class InternalIpv4AddressSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    address: builtins.str
    """IPv4 address."""
    subnet_id: builtins.str
    """ID of the subnet that the address belongs to."""
    def __init__(
        self,
        *,
        address: builtins.str = ...,
        subnet_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["address", b"address", "subnet_id", b"subnet_id"]) -> None: ...

global___InternalIpv4AddressSpec = InternalIpv4AddressSpec

@typing.final
class ExternalIpv6AddressSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_FIELD_NUMBER: builtins.int
    address: builtins.str
    """IPv6 address."""
    def __init__(
        self,
        *,
        address: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["address", b"address"]) -> None: ...

global___ExternalIpv6AddressSpec = ExternalIpv6AddressSpec

@typing.final
class EndpointSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_SPECS_FIELD_NUMBER: builtins.int
    PORTS_FIELD_NUMBER: builtins.int
    @property
    def address_specs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AddressSpec]:
        """Endpoint public (external) and internal addresses."""

    @property
    def ports(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """Endpoint ports."""

    def __init__(
        self,
        *,
        address_specs: collections.abc.Iterable[global___AddressSpec] | None = ...,
        ports: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["address_specs", b"address_specs", "ports", b"ports"]) -> None: ...

global___EndpointSpec = EndpointSpec

@typing.final
class ListenerSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    ENDPOINT_SPECS_FIELD_NUMBER: builtins.int
    HTTP_FIELD_NUMBER: builtins.int
    TLS_FIELD_NUMBER: builtins.int
    STREAM_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the listener. The name is unique within the application load balancer."""
    @property
    def endpoint_specs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EndpointSpec]:
        """Endpoints of the listener.

        Endpoints are defined by their IP addresses and ports.
        """

    @property
    def http(self) -> yandex.cloud.apploadbalancer.v1.load_balancer_pb2.HttpListener:
        """Unencrypted HTTP listener settings."""

    @property
    def tls(self) -> yandex.cloud.apploadbalancer.v1.load_balancer_pb2.TlsListener:
        """TLS-encrypted HTTP or TCP stream listener settings.

        All handlers within a listener ([TlsListener.default_handler] and [TlsListener.sni_handlers]) must be of one
        type, [HttpHandler] or [StreamHandler]. Mixing HTTP and TCP stream traffic in a TLS-encrypted listener is not
        supported.
        """

    @property
    def stream(self) -> yandex.cloud.apploadbalancer.v1.load_balancer_pb2.StreamListener:
        """Unencrypted stream (TCP) listener settings."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        endpoint_specs: collections.abc.Iterable[global___EndpointSpec] | None = ...,
        http: yandex.cloud.apploadbalancer.v1.load_balancer_pb2.HttpListener | None = ...,
        tls: yandex.cloud.apploadbalancer.v1.load_balancer_pb2.TlsListener | None = ...,
        stream: yandex.cloud.apploadbalancer.v1.load_balancer_pb2.StreamListener | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["http", b"http", "listener", b"listener", "stream", b"stream", "tls", b"tls"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["endpoint_specs", b"endpoint_specs", "http", b"http", "listener", b"listener", "name", b"name", "stream", b"stream", "tls", b"tls"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["listener", b"listener"]) -> typing.Literal["http", "tls", "stream"] | None: ...

global___ListenerSpec = ListenerSpec

@typing.final
class GetTargetStatesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOAD_BALANCER_ID_FIELD_NUMBER: builtins.int
    BACKEND_GROUP_ID_FIELD_NUMBER: builtins.int
    TARGET_GROUP_ID_FIELD_NUMBER: builtins.int
    load_balancer_id: builtins.str
    """ID of the application load balancer that the backend group is attributed to."""
    backend_group_id: builtins.str
    """ID of the backend group that the target group is attributed to."""
    target_group_id: builtins.str
    """ID of the target group to get target states of."""
    def __init__(
        self,
        *,
        load_balancer_id: builtins.str = ...,
        backend_group_id: builtins.str = ...,
        target_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["backend_group_id", b"backend_group_id", "load_balancer_id", b"load_balancer_id", "target_group_id", b"target_group_id"]) -> None: ...

global___GetTargetStatesRequest = GetTargetStatesRequest

@typing.final
class GetTargetStatesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARGET_STATES_FIELD_NUMBER: builtins.int
    @property
    def target_states(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.apploadbalancer.v1.load_balancer_pb2.TargetState]:
        """Target states of the specified target group."""

    def __init__(
        self,
        *,
        target_states: collections.abc.Iterable[yandex.cloud.apploadbalancer.v1.load_balancer_pb2.TargetState] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["target_states", b"target_states"]) -> None: ...

global___GetTargetStatesResponse = GetTargetStatesResponse

@typing.final
class AddSniMatchRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOAD_BALANCER_ID_FIELD_NUMBER: builtins.int
    LISTENER_NAME_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SERVER_NAMES_FIELD_NUMBER: builtins.int
    HANDLER_FIELD_NUMBER: builtins.int
    load_balancer_id: builtins.str
    """ID of the application load balancer to add a SNI handler to."""
    listener_name: builtins.str
    """Name of the listener to add a SNI handler to."""
    name: builtins.str
    """Name of the SNI handler to add."""
    @property
    def server_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Server names that are matched by the SNI handler."""

    @property
    def handler(self) -> yandex.cloud.apploadbalancer.v1.load_balancer_pb2.TlsHandler:
        """Settings for handling requests with Server Name Indication (SNI) matching one of [server_names] values."""

    def __init__(
        self,
        *,
        load_balancer_id: builtins.str = ...,
        listener_name: builtins.str = ...,
        name: builtins.str = ...,
        server_names: collections.abc.Iterable[builtins.str] | None = ...,
        handler: yandex.cloud.apploadbalancer.v1.load_balancer_pb2.TlsHandler | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["handler", b"handler"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["handler", b"handler", "listener_name", b"listener_name", "load_balancer_id", b"load_balancer_id", "name", b"name", "server_names", b"server_names"]) -> None: ...

global___AddSniMatchRequest = AddSniMatchRequest

@typing.final
class AddSniMatchMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOAD_BALANCER_ID_FIELD_NUMBER: builtins.int
    LISTENER_NAME_FIELD_NUMBER: builtins.int
    SNI_MATCH_NAME_FIELD_NUMBER: builtins.int
    load_balancer_id: builtins.str
    """ID of the application load balancer that the SNI handler is being added to."""
    listener_name: builtins.str
    """Name of the listener that the SNI handler is being added to."""
    sni_match_name: builtins.str
    """Name of the SNI handler that is being added to the listener."""
    def __init__(
        self,
        *,
        load_balancer_id: builtins.str = ...,
        listener_name: builtins.str = ...,
        sni_match_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["listener_name", b"listener_name", "load_balancer_id", b"load_balancer_id", "sni_match_name", b"sni_match_name"]) -> None: ...

global___AddSniMatchMetadata = AddSniMatchMetadata

@typing.final
class RemoveSniMatchRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOAD_BALANCER_ID_FIELD_NUMBER: builtins.int
    LISTENER_NAME_FIELD_NUMBER: builtins.int
    SNI_MATCH_NAME_FIELD_NUMBER: builtins.int
    load_balancer_id: builtins.str
    """ID of the application load balancer to remove the SNI handler from."""
    listener_name: builtins.str
    """Name of the listener te remove the SNI handler from."""
    sni_match_name: builtins.str
    """Name of the SNI handler to remove."""
    def __init__(
        self,
        *,
        load_balancer_id: builtins.str = ...,
        listener_name: builtins.str = ...,
        sni_match_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["listener_name", b"listener_name", "load_balancer_id", b"load_balancer_id", "sni_match_name", b"sni_match_name"]) -> None: ...

global___RemoveSniMatchRequest = RemoveSniMatchRequest

@typing.final
class RemoveSniMatchMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOAD_BALANCER_ID_FIELD_NUMBER: builtins.int
    LISTENER_NAME_FIELD_NUMBER: builtins.int
    SNI_MATCH_NAME_FIELD_NUMBER: builtins.int
    load_balancer_id: builtins.str
    """ID of the application load balancer that the SNI handler is being removed from."""
    listener_name: builtins.str
    """Name of the listener that the SNI handler is being removed from."""
    sni_match_name: builtins.str
    """Name of the SNI handler that is being removed."""
    def __init__(
        self,
        *,
        load_balancer_id: builtins.str = ...,
        listener_name: builtins.str = ...,
        sni_match_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["listener_name", b"listener_name", "load_balancer_id", b"load_balancer_id", "sni_match_name", b"sni_match_name"]) -> None: ...

global___RemoveSniMatchMetadata = RemoveSniMatchMetadata

@typing.final
class UpdateSniMatchRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOAD_BALANCER_ID_FIELD_NUMBER: builtins.int
    LISTENER_NAME_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    SERVER_NAMES_FIELD_NUMBER: builtins.int
    HANDLER_FIELD_NUMBER: builtins.int
    load_balancer_id: builtins.str
    """ID of the application load balancer to update the SNI handler in."""
    listener_name: builtins.str
    """Name of the listener to update the SNI handler in."""
    name: builtins.str
    """Name of the SNI handler to update."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which attributes of the SNI handler should be updated."""

    @property
    def server_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """New server names that are matched by the SNI handler.

        Existing set of server names is completely replaced by the provided set, so if you just want
        to add or remove a server name:
        1. Get the current set of server names with a [LoadBalancerService.Get] request.
        2. Add or remove a server name in this set.
        3. Send the new set in this field.
        """

    @property
    def handler(self) -> yandex.cloud.apploadbalancer.v1.load_balancer_pb2.TlsHandler:
        """New settings for handling requests with Server Name Indication (SNI) matching one of [server_names] values."""

    def __init__(
        self,
        *,
        load_balancer_id: builtins.str = ...,
        listener_name: builtins.str = ...,
        name: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        server_names: collections.abc.Iterable[builtins.str] | None = ...,
        handler: yandex.cloud.apploadbalancer.v1.load_balancer_pb2.TlsHandler | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["handler", b"handler", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["handler", b"handler", "listener_name", b"listener_name", "load_balancer_id", b"load_balancer_id", "name", b"name", "server_names", b"server_names", "update_mask", b"update_mask"]) -> None: ...

global___UpdateSniMatchRequest = UpdateSniMatchRequest

@typing.final
class UpdateSniMatchMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOAD_BALANCER_ID_FIELD_NUMBER: builtins.int
    LISTENER_NAME_FIELD_NUMBER: builtins.int
    SNI_MATCH_NAME_FIELD_NUMBER: builtins.int
    load_balancer_id: builtins.str
    """ID of the application load balancer that the SNI handler is being updated in."""
    listener_name: builtins.str
    """Name of the listener that the SNI handler is being updated in."""
    sni_match_name: builtins.str
    """Name of the SNI handler that is being updated."""
    def __init__(
        self,
        *,
        load_balancer_id: builtins.str = ...,
        listener_name: builtins.str = ...,
        sni_match_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["listener_name", b"listener_name", "load_balancer_id", b"load_balancer_id", "sni_match_name", b"sni_match_name"]) -> None: ...

global___UpdateSniMatchMetadata = UpdateSniMatchMetadata

@typing.final
class ListLoadBalancerOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOAD_BALANCER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    load_balancer_id: builtins.str
    """ID of the application load balancer to get operations for.

    To get the application load balancer ID, use a [LoadBalancerService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page that should be returned. If the number of available
    results is larger than [page_size], the service returns a [ListLoadBalancerOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListLoadBalancerOperationsResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        load_balancer_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["load_balancer_id", b"load_balancer_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListLoadBalancerOperationsRequest = ListLoadBalancerOperationsRequest

@typing.final
class ListLoadBalancerOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListLoadBalancerOperationsRequest.page_size], use `next_page_token` as the value
    for the [ListLoadBalancerOperationsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified application load balancer."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListLoadBalancerOperationsResponse = ListLoadBalancerOperationsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Subtitle(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _SubtitleStatus:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _SubtitleStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Subtitle._SubtitleStatus.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SUBTITLE_STATUS_UNSPECIFIED: Subtitle._SubtitleStatus.ValueType  # 0
        """Subtitle status unspecified."""
        WAIT_UPLOADING: Subtitle._SubtitleStatus.ValueType  # 1
        """Waiting for all the bytes to be loaded."""
        UPLOADED: Subtitle._SubtitleStatus.ValueType  # 2
        """Uploading is complete."""

    class SubtitleStatus(_SubtitleStatus, metaclass=_SubtitleStatusEnumTypeWrapper): ...
    SUBTITLE_STATUS_UNSPECIFIED: Subtitle.SubtitleStatus.ValueType  # 0
    """Subtitle status unspecified."""
    WAIT_UPLOADING: Subtitle.SubtitleStatus.ValueType  # 1
    """Waiting for all the bytes to be loaded."""
    UPLOADED: Subtitle.SubtitleStatus.ValueType  # 2
    """Uploading is complete."""

    class _SubtitleSourceType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _SubtitleSourceTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Subtitle._SubtitleSourceType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SUBTITLE_SOURCE_TYPE_UNSPECIFIED: Subtitle._SubtitleSourceType.ValueType  # 0
        """Subtitle source type unspecified."""
        MANUAL: Subtitle._SubtitleSourceType.ValueType  # 1
        """Manually uploaded subtitle."""
        GENERATED: Subtitle._SubtitleSourceType.ValueType  # 2
        """Automatically generated subtitle."""

    class SubtitleSourceType(_SubtitleSourceType, metaclass=_SubtitleSourceTypeEnumTypeWrapper): ...
    SUBTITLE_SOURCE_TYPE_UNSPECIFIED: Subtitle.SubtitleSourceType.ValueType  # 0
    """Subtitle source type unspecified."""
    MANUAL: Subtitle.SubtitleSourceType.ValueType  # 1
    """Manually uploaded subtitle."""
    GENERATED: Subtitle.SubtitleSourceType.ValueType  # 2
    """Automatically generated subtitle."""

    ID_FIELD_NUMBER: builtins.int
    LANGUAGE_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    SOURCE_TYPE_FIELD_NUMBER: builtins.int
    FILENAME_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    VIDEO_ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the subtitle."""
    language: builtins.str
    """Subtitle language in any of the following formats:
    * three-letter code according to ISO 639-2/T, ISO 639-2/B, or ISO 639-3
    * two-letter code according to ISO 639-1
    """
    label: builtins.str
    """Subtitle caption to be displayed on screen during video playback."""
    status: global___Subtitle.SubtitleStatus.ValueType
    """Subtitle status."""
    source_type: global___Subtitle.SubtitleSourceType.ValueType
    """Source type."""
    filename: builtins.str
    """Subtitle filename."""
    video_id: builtins.str
    """ID of the video."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when subtitle was created."""

    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time of last subtitle update."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        language: builtins.str = ...,
        label: builtins.str = ...,
        status: global___Subtitle.SubtitleStatus.ValueType = ...,
        source_type: global___Subtitle.SubtitleSourceType.ValueType = ...,
        filename: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        video_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "parent_id", b"parent_id", "updated_at", b"updated_at", "video_id", b"video_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "filename", b"filename", "id", b"id", "label", b"label", "language", b"language", "parent_id", b"parent_id", "source_type", b"source_type", "status", b"status", "updated_at", b"updated_at", "video_id", b"video_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["parent_id", b"parent_id"]) -> typing.Literal["video_id"] | None: ...

global___Subtitle = Subtitle



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.video.v1.subtitle_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetSubtitleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBTITLE_ID_FIELD_NUMBER: builtins.int
    subtitle_id: builtins.str
    """ID of the subtitle."""
    def __init__(
        self,
        *,
        subtitle_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["subtitle_id", b"subtitle_id"]) -> None: ...

global___GetSubtitleRequest = GetSubtitleRequest

@typing.final
class ListSubtitlesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    VIDEO_ID_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """The maximum number of the results per page to return.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token for getting the next page of the result."""
    video_id: builtins.str
    """ID of the video."""
    def __init__(
        self,
        *,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        video_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["parent_id", b"parent_id", "video_id", b"video_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token", "parent_id", b"parent_id", "video_id", b"video_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["parent_id", b"parent_id"]) -> typing.Literal["video_id"] | None: ...

global___ListSubtitlesRequest = ListSubtitlesRequest

@typing.final
class ListSubtitlesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBTITLES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page."""
    @property
    def subtitles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.video.v1.subtitle_pb2.Subtitle]: ...
    def __init__(
        self,
        *,
        subtitles: collections.abc.Iterable[yandex.cloud.video.v1.subtitle_pb2.Subtitle] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "subtitles", b"subtitles"]) -> None: ...

global___ListSubtitlesResponse = ListSubtitlesResponse

@typing.final
class CreateSubtitleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LANGUAGE_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    VIDEO_ID_FIELD_NUMBER: builtins.int
    UPLOAD_FIELD_NUMBER: builtins.int
    language: builtins.str
    """Subtitle language in any of the following formats:
    * three-letter code according to ISO 639-2/T, ISO 639-2/B, or ISO 639-3
    * two-letter code according to ISO 639-1
    """
    label: builtins.str
    """Contains the subtitle label (or title) that will be displayed on screen during video playback.
    Should provide a concise and accurate representation of the spoken content.
    If not provided, it will be auto-generated based on the specified language.
    """
    video_id: builtins.str
    """ID of the video."""
    @property
    def upload(self) -> global___SubtitleUploadParams:
        """Upload subtitle."""

    def __init__(
        self,
        *,
        language: builtins.str = ...,
        label: builtins.str = ...,
        video_id: builtins.str = ...,
        upload: global___SubtitleUploadParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["parent_id", b"parent_id", "source", b"source", "upload", b"upload", "video_id", b"video_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["label", b"label", "language", b"language", "parent_id", b"parent_id", "source", b"source", "upload", b"upload", "video_id", b"video_id"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["parent_id", b"parent_id"]) -> typing.Literal["video_id"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["source", b"source"]) -> typing.Literal["upload"] | None: ...

global___CreateSubtitleRequest = CreateSubtitleRequest

@typing.final
class SubtitleUploadParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILENAME_FIELD_NUMBER: builtins.int
    filename: builtins.str
    def __init__(
        self,
        *,
        filename: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filename", b"filename"]) -> None: ...

global___SubtitleUploadParams = SubtitleUploadParams

@typing.final
class CreateSubtitleMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBTITLE_ID_FIELD_NUMBER: builtins.int
    subtitle_id: builtins.str
    """ID of the subtitle."""
    def __init__(
        self,
        *,
        subtitle_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["subtitle_id", b"subtitle_id"]) -> None: ...

global___CreateSubtitleMetadata = CreateSubtitleMetadata

@typing.final
class GenerateSubtitleUploadURLRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBTITLE_ID_FIELD_NUMBER: builtins.int
    subtitle_id: builtins.str
    """ID of the subtitle."""
    def __init__(
        self,
        *,
        subtitle_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["subtitle_id", b"subtitle_id"]) -> None: ...

global___GenerateSubtitleUploadURLRequest = GenerateSubtitleUploadURLRequest

@typing.final
class GenerateSubtitleUploadURLResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UPLOAD_URL_FIELD_NUMBER: builtins.int
    upload_url: builtins.str
    """Upload url."""
    def __init__(
        self,
        *,
        upload_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["upload_url", b"upload_url"]) -> None: ...

global___GenerateSubtitleUploadURLResponse = GenerateSubtitleUploadURLResponse

@typing.final
class DeleteSubtitleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBTITLE_ID_FIELD_NUMBER: builtins.int
    subtitle_id: builtins.str
    """ID of the subtitle."""
    def __init__(
        self,
        *,
        subtitle_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["subtitle_id", b"subtitle_id"]) -> None: ...

global___DeleteSubtitleRequest = DeleteSubtitleRequest

@typing.final
class DeleteSubtitleMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBTITLE_ID_FIELD_NUMBER: builtins.int
    subtitle_id: builtins.str
    """ID of the subtitle."""
    def __init__(
        self,
        *,
        subtitle_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["subtitle_id", b"subtitle_id"]) -> None: ...

global___DeleteSubtitleMetadata = DeleteSubtitleMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.iam.v1.iam_token_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class IamTokenServiceStub:
    """A set of methods for managing IAM tokens."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.iam_token_service_pb2.CreateIamTokenRequest,
        yandex.cloud.iam.v1.iam_token_service_pb2.CreateIamTokenResponse,
    ]
    """Create an IAM token for the specified identity."""

    CreateForServiceAccount: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.iam_token_service_pb2.CreateIamTokenForServiceAccountRequest,
        yandex.cloud.iam.v1.iam_token_service_pb2.CreateIamTokenResponse,
    ]
    """Create an IAM token for service account."""

    Revoke: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.iam_token_service_pb2.RevokeIamTokenRequest,
        yandex.cloud.iam.v1.iam_token_service_pb2.RevokeIamTokenResponse,
    ]
    """Revoke the IAM token."""

class IamTokenServiceAsyncStub:
    """A set of methods for managing IAM tokens."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.iam_token_service_pb2.CreateIamTokenRequest,
        yandex.cloud.iam.v1.iam_token_service_pb2.CreateIamTokenResponse,
    ]
    """Create an IAM token for the specified identity."""

    CreateForServiceAccount: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.iam_token_service_pb2.CreateIamTokenForServiceAccountRequest,
        yandex.cloud.iam.v1.iam_token_service_pb2.CreateIamTokenResponse,
    ]
    """Create an IAM token for service account."""

    Revoke: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.iam_token_service_pb2.RevokeIamTokenRequest,
        yandex.cloud.iam.v1.iam_token_service_pb2.RevokeIamTokenResponse,
    ]
    """Revoke the IAM token."""

class IamTokenServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing IAM tokens."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.iam.v1.iam_token_service_pb2.CreateIamTokenRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.iam.v1.iam_token_service_pb2.CreateIamTokenResponse, collections.abc.Awaitable[yandex.cloud.iam.v1.iam_token_service_pb2.CreateIamTokenResponse]]:
        """Create an IAM token for the specified identity."""

    @abc.abstractmethod
    def CreateForServiceAccount(
        self,
        request: yandex.cloud.iam.v1.iam_token_service_pb2.CreateIamTokenForServiceAccountRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.iam.v1.iam_token_service_pb2.CreateIamTokenResponse, collections.abc.Awaitable[yandex.cloud.iam.v1.iam_token_service_pb2.CreateIamTokenResponse]]:
        """Create an IAM token for service account."""

    @abc.abstractmethod
    def Revoke(
        self,
        request: yandex.cloud.iam.v1.iam_token_service_pb2.RevokeIamTokenRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.iam.v1.iam_token_service_pb2.RevokeIamTokenResponse, collections.abc.Awaitable[yandex.cloud.iam.v1.iam_token_service_pb2.RevokeIamTokenResponse]]:
        """Revoke the IAM token."""

def add_IamTokenServiceServicer_to_server(servicer: IamTokenServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/smartcaptcha/v1/captcha_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/smartcaptcha/v1/captcha_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.smartcaptcha.v1 import captcha_pb2 as yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2yandex/cloud/smartcaptcha/v1/captcha_service.proto\x12\x1cyandex.cloud.smartcaptcha.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a&yandex/cloud/operation/operation.proto\x1a*yandex/cloud/smartcaptcha/v1/captcha.proto\"5\n\x11GetCaptchaRequest\x12 \n\ncaptcha_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"6\n\x13ListCaptchasRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\\\n\x14ListCaptchasResponse\x12\x38\n\tresources\x18\x03 \x03(\x0b\x32%.yandex.cloud.smartcaptcha.v1.CaptchaJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03\"\xca\x04\n\x14\x43reateCaptchaRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\x04name\x18\x02 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x15\n\rallowed_sites\x18\x03 \x03(\t\x12\x43\n\ncomplexity\x18\x04 \x01(\x0e\x32/.yandex.cloud.smartcaptcha.v1.CaptchaComplexity\x12\x12\n\nstyle_json\x18\x05 \x01(\t\x12\x1f\n\x17turn_off_hostname_check\x18\x06 \x01(\x08\x12I\n\x0epre_check_type\x18\x08 \x01(\x0e\x32\x31.yandex.cloud.smartcaptcha.v1.CaptchaPreCheckType\x12J\n\x0e\x63hallenge_type\x18\t \x01(\x0e\x32\x32.yandex.cloud.smartcaptcha.v1.CaptchaChallengeType\x12\x42\n\x0esecurity_rules\x18\x0b \x03(\x0b\x32*.yandex.cloud.smartcaptcha.v1.SecurityRule\x12\x1b\n\x13\x64\x65letion_protection\x18\x0c \x01(\x08\x12H\n\x11override_variants\x18\r \x03(\x0b\x32-.yandex.cloud.smartcaptcha.v1.OverrideVariantJ\x04\x08\x07\x10\x08J\x04\x08\n\x10\x0b\"+\n\x15\x43reateCaptchaMetadata\x12\x12\n\ncaptcha_id\x18\x01 \x01(\t\"8\n\x14\x44\x65leteCaptchaRequest\x12 \n\ncaptcha_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x15\x44\x65leteCaptchaMetadata\x12\x12\n\ncaptcha_id\x18\x01 \x01(\t\"\xfc\x04\n\x14UpdateCaptchaRequest\x12 \n\ncaptcha_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x15\n\rallowed_sites\x18\x04 \x03(\t\x12\x43\n\ncomplexity\x18\x05 \x01(\x0e\x32/.yandex.cloud.smartcaptcha.v1.CaptchaComplexity\x12\x12\n\nstyle_json\x18\x06 \x01(\t\x12\x1f\n\x17turn_off_hostname_check\x18\x07 \x01(\x08\x12I\n\x0epre_check_type\x18\t \x01(\x0e\x32\x31.yandex.cloud.smartcaptcha.v1.CaptchaPreCheckType\x12J\n\x0e\x63hallenge_type\x18\n \x01(\x0e\x32\x32.yandex.cloud.smartcaptcha.v1.CaptchaChallengeType\x12\x42\n\x0esecurity_rules\x18\x0c \x03(\x0b\x32*.yandex.cloud.smartcaptcha.v1.SecurityRule\x12\x1b\n\x13\x64\x65letion_protection\x18\r \x01(\x08\x12H\n\x11override_variants\x18\x0e \x03(\x0b\x32-.yandex.cloud.smartcaptcha.v1.OverrideVariantJ\x04\x08\x08\x10\tJ\x04\x08\x0b\x10\x0c\"+\n\x15UpdateCaptchaMetadata\x12\x12\n\ncaptcha_id\x18\x01 \x01(\t2\x8b\x08\n\x0e\x43\x61ptchaService\x12\x8d\x01\n\x03Get\x12/.yandex.cloud.smartcaptcha.v1.GetCaptchaRequest\x1a%.yandex.cloud.smartcaptcha.v1.Captcha\".\x82\xd3\xe4\x93\x02(\x12&/smartcaptcha/v1/captchas/{captcha_id}\x12\xac\x01\n\x0cGetSecretKey\x12/.yandex.cloud.smartcaptcha.v1.GetCaptchaRequest\x1a..yandex.cloud.smartcaptcha.v1.CaptchaSecretKey\";\x82\xd3\xe4\x93\x02\x35\x12\x33/smartcaptcha/v1/captchas/{captcha_id}:getSecretKey\x12\x90\x01\n\x04List\x12\x31.yandex.cloud.smartcaptcha.v1.ListCaptchasRequest\x1a\x32.yandex.cloud.smartcaptcha.v1.ListCaptchasResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/smartcaptcha/v1/captchas\x12\xa9\x01\n\x06\x43reate\x12\x32.yandex.cloud.smartcaptcha.v1.CreateCaptchaRequest\x1a!.yandex.cloud.operation.Operation\"H\xb2\xd2* \n\x15\x43reateCaptchaMetadata\x12\x07\x43\x61ptcha\x82\xd3\xe4\x93\x02\x1e\"\x19/smartcaptcha/v1/captchas:\x01*\x12\xb6\x01\n\x06Update\x12\x32.yandex.cloud.smartcaptcha.v1.UpdateCaptchaRequest\x1a!.yandex.cloud.operation.Operation\"U\xb2\xd2* \n\x15UpdateCaptchaMetadata\x12\x07\x43\x61ptcha\x82\xd3\xe4\x93\x02+2&/smartcaptcha/v1/captchas/{captcha_id}:\x01*\x12\xc1\x01\n\x06\x44\x65lete\x12\x32.yandex.cloud.smartcaptcha.v1.DeleteCaptchaRequest\x1a!.yandex.cloud.operation.Operation\"`\xb2\xd2*.\n\x15\x44\x65leteCaptchaMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02(*&/smartcaptcha/v1/captchas/{captcha_id}Bq\n yandex.cloud.api.smartcaptcha.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/smartcaptcha/v1;smartcaptchab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.smartcaptcha.v1.captcha_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n yandex.cloud.api.smartcaptcha.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/smartcaptcha/v1;smartcaptcha'
  _globals['_GETCAPTCHAREQUEST'].fields_by_name['captcha_id']._loaded_options = None
  _globals['_GETCAPTCHAREQUEST'].fields_by_name['captcha_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCAPTCHASREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTCAPTCHASREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATECAPTCHAREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATECAPTCHAREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATECAPTCHAREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATECAPTCHAREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _globals['_DELETECAPTCHAREQUEST'].fields_by_name['captcha_id']._loaded_options = None
  _globals['_DELETECAPTCHAREQUEST'].fields_by_name['captcha_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATECAPTCHAREQUEST'].fields_by_name['captcha_id']._loaded_options = None
  _globals['_UPDATECAPTCHAREQUEST'].fields_by_name['captcha_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATECAPTCHAREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATECAPTCHAREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _globals['_CAPTCHASERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_CAPTCHASERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002(\022&/smartcaptcha/v1/captchas/{captcha_id}'
  _globals['_CAPTCHASERVICE'].methods_by_name['GetSecretKey']._loaded_options = None
  _globals['_CAPTCHASERVICE'].methods_by_name['GetSecretKey']._serialized_options = b'\202\323\344\223\0025\0223/smartcaptcha/v1/captchas/{captcha_id}:getSecretKey'
  _globals['_CAPTCHASERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_CAPTCHASERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\033\022\031/smartcaptcha/v1/captchas'
  _globals['_CAPTCHASERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_CAPTCHASERVICE'].methods_by_name['Create']._serialized_options = b'\262\322* \n\025CreateCaptchaMetadata\022\007Captcha\202\323\344\223\002\036\"\031/smartcaptcha/v1/captchas:\001*'
  _globals['_CAPTCHASERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_CAPTCHASERVICE'].methods_by_name['Update']._serialized_options = b'\262\322* \n\025UpdateCaptchaMetadata\022\007Captcha\202\323\344\223\002+2&/smartcaptcha/v1/captchas/{captcha_id}:\001*'
  _globals['_CAPTCHASERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_CAPTCHASERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*.\n\025DeleteCaptchaMetadata\022\025google.protobuf.Empty\202\323\344\223\002(*&/smartcaptcha/v1/captchas/{captcha_id}'
  _globals['_GETCAPTCHAREQUEST']._serialized_start=297
  _globals['_GETCAPTCHAREQUEST']._serialized_end=350
  _globals['_LISTCAPTCHASREQUEST']._serialized_start=352
  _globals['_LISTCAPTCHASREQUEST']._serialized_end=406
  _globals['_LISTCAPTCHASRESPONSE']._serialized_start=408
  _globals['_LISTCAPTCHASRESPONSE']._serialized_end=500
  _globals['_CREATECAPTCHAREQUEST']._serialized_start=503
  _globals['_CREATECAPTCHAREQUEST']._serialized_end=1089
  _globals['_CREATECAPTCHAMETADATA']._serialized_start=1091
  _globals['_CREATECAPTCHAMETADATA']._serialized_end=1134
  _globals['_DELETECAPTCHAREQUEST']._serialized_start=1136
  _globals['_DELETECAPTCHAREQUEST']._serialized_end=1192
  _globals['_DELETECAPTCHAMETADATA']._serialized_start=1194
  _globals['_DELETECAPTCHAMETADATA']._serialized_end=1237
  _globals['_UPDATECAPTCHAREQUEST']._serialized_start=1240
  _globals['_UPDATECAPTCHAREQUEST']._serialized_end=1876
  _globals['_UPDATECAPTCHAMETADATA']._serialized_start=1878
  _globals['_UPDATECAPTCHAMETADATA']._serialized_end=1921
  _globals['_CAPTCHASERVICE']._serialized_start=1924
  _globals['_CAPTCHASERVICE']._serialized_end=2959
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class NodeExecutionErrorDetails(google.protobuf.message.Message):
    """User code python execution's error details"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ERROR_NAME_FIELD_NUMBER: builtins.int
    ERROR_MESSAGE_FIELD_NUMBER: builtins.int
    TRACEBACK_FIELD_NUMBER: builtins.int
    error_name: builtins.str
    """Error name"""
    error_message: builtins.str
    """Error message"""
    @property
    def traceback(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Error traceback"""

    def __init__(
        self,
        *,
        error_name: builtins.str = ...,
        error_message: builtins.str = ...,
        traceback: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["error_message", b"error_message", "error_name", b"error_name", "traceback", b"traceback"]) -> None: ...

global___NodeExecutionErrorDetails = NodeExecutionErrorDetails



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/video/v1/stream_line.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/video/v1/stream_line.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'yandex/cloud/video/v1/stream_line.proto\x12\x15yandex.cloud.video.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xca\x04\n\nStreamLine\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x14\n\x0cthumbnail_id\x18\x04 \x01(\t\x12:\n\trtmp_push\x18\xe8\x07 \x01(\x0b\x32$.yandex.cloud.video.v1.RTMPPushInputH\x00\x12:\n\trtmp_pull\x18\xea\x07 \x01(\x0b\x32$.yandex.cloud.video.v1.RTMPPullInputH\x00\x12\x39\n\x0bmanual_line\x18\xd0\x0f \x01(\x0b\x32!.yandex.cloud.video.v1.ManualLineH\x01\x12\x35\n\tauto_line\x18\xd1\x0f \x01(\x0b\x32\x1f.yandex.cloud.video.v1.AutoLineH\x01\x12.\n\ncreated_at\x18\x64 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x65 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12>\n\x06labels\x18\xc8\x01 \x03(\x0b\x32-.yandex.cloud.video.v1.StreamLine.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0c\n\ninput_typeB\x0b\n\tline_typeJ\x04\x08\x05\x10\x64J\x05\x08\x66\x10\xc8\x01J\x06\x08\xc9\x01\x10\xe8\x07J\x06\x08\xe9\x07\x10\xea\x07J\x06\x08\xeb\x07\x10\xd0\x0f\"\x1c\n\rPushStreamKey\x12\x0b\n\x03key\x18\x01 \x01(\t\"\x1c\n\rRTMPPushInput\x12\x0b\n\x03url\x18\x01 \x01(\t\"\x1c\n\rRTMPPullInput\x12\x0b\n\x03url\x18\x01 \x01(\t\"\x0c\n\nManualLine\"\x9b\x01\n\x08\x41utoLine\x12>\n\x06status\x18\x01 \x01(\x0e\x32..yandex.cloud.video.v1.AutoLine.AutoLineStatus\"O\n\x0e\x41utoLineStatus\x12 \n\x1c\x41UTO_LINE_STATUS_UNSPECIFIED\x10\x00\x12\x0f\n\x0b\x44\x45\x41\x43TIVATED\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x42\\\n\x19yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;videob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.video.v1.stream_line_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;video'
  _globals['_STREAMLINE_LABELSENTRY']._loaded_options = None
  _globals['_STREAMLINE_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_STREAMLINE']._serialized_start=100
  _globals['_STREAMLINE']._serialized_end=686
  _globals['_STREAMLINE_LABELSENTRY']._serialized_start=577
  _globals['_STREAMLINE_LABELSENTRY']._serialized_end=622
  _globals['_PUSHSTREAMKEY']._serialized_start=688
  _globals['_PUSHSTREAMKEY']._serialized_end=716
  _globals['_RTMPPUSHINPUT']._serialized_start=718
  _globals['_RTMPPUSHINPUT']._serialized_end=746
  _globals['_RTMPPULLINPUT']._serialized_start=748
  _globals['_RTMPPULLINPUT']._serialized_end=776
  _globals['_MANUALLINE']._serialized_start=778
  _globals['_MANUALLINE']._serialized_end=790
  _globals['_AUTOLINE']._serialized_start=793
  _globals['_AUTOLINE']._serialized_end=948
  _globals['_AUTOLINE_AUTOLINESTATUS']._serialized_start=869
  _globals['_AUTOLINE_AUTOLINESTATUS']._serialized_end=948
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yandex.cloud.ai.foundation_models.v1.text_classification import text_classification_service_pb2 as yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__classification_dot_text__classification__service__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in yandex/cloud/ai/foundation_models/v1/text_classification/text_classification_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class TextClassificationServiceStub(object):
    """Service for classifying the text requests provided in prompts.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Classify = channel.unary_unary(
                '/yandex.cloud.ai.foundation_models.v1.text_classification.TextClassificationService/Classify',
                request_serializer=yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__classification_dot_text__classification__service__pb2.TextClassificationRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__classification_dot_text__classification__service__pb2.TextClassificationResponse.FromString,
                _registered_method=True)
        self.FewShotClassify = channel.unary_unary(
                '/yandex.cloud.ai.foundation_models.v1.text_classification.TextClassificationService/FewShotClassify',
                request_serializer=yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__classification_dot_text__classification__service__pb2.FewShotTextClassificationRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__classification_dot_text__classification__service__pb2.FewShotTextClassificationResponse.FromString,
                _registered_method=True)


class TextClassificationServiceServicer(object):
    """Service for classifying the text requests provided in prompts.
    """

    def Classify(self, request, context):
        """RPC method to classify text with tuned model.

        The names of the classes between which the model will be distributing requests 
        must be specified during model tuning and are not provided in the request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FewShotClassify(self, request, context):
        """RPC method for binary and multi-class classification. 

        You can provide up to 20 classes for few-shot text classification
        with optional examples.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TextClassificationServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Classify': grpc.unary_unary_rpc_method_handler(
                    servicer.Classify,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__classification_dot_text__classification__service__pb2.TextClassificationRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__classification_dot_text__classification__service__pb2.TextClassificationResponse.SerializeToString,
            ),
            'FewShotClassify': grpc.unary_unary_rpc_method_handler(
                    servicer.FewShotClassify,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__classification_dot_text__classification__service__pb2.FewShotTextClassificationRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__classification_dot_text__classification__service__pb2.FewShotTextClassificationResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.ai.foundation_models.v1.text_classification.TextClassificationService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('yandex.cloud.ai.foundation_models.v1.text_classification.TextClassificationService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class TextClassificationService(object):
    """Service for classifying the text requests provided in prompts.
    """

    @staticmethod
    def Classify(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.ai.foundation_models.v1.text_classification.TextClassificationService/Classify',
            yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__classification_dot_text__classification__service__pb2.TextClassificationRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__classification_dot_text__classification__service__pb2.TextClassificationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def FewShotClassify(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.ai.foundation_models.v1.text_classification.TextClassificationService/FewShotClassify',
            yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__classification_dot_text__classification__service__pb2.FewShotTextClassificationRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__classification_dot_text__classification__service__pb2.FewShotTextClassificationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.vpc.v1.network_pb2
import yandex.cloud.vpc.v1.route_table_pb2
import yandex.cloud.vpc.v1.security_group_pb2
import yandex.cloud.vpc.v1.subnet_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetNetworkRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_ID_FIELD_NUMBER: builtins.int
    network_id: builtins.str
    """ID of the Network resource to return.
    To get the network ID, use a [NetworkService.List] request.
    """
    def __init__(
        self,
        *,
        network_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["network_id", b"network_id"]) -> None: ...

global___GetNetworkRequest = GetNetworkRequest

@typing.final
class ListNetworksRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list networks in.
    To get the folder ID, use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListNetworksResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests. Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListNetworksResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression must specify:
    1. The field name. Currently you can use filtering only on the [Network.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListNetworksRequest = ListNetworksRequest

@typing.final
class ListNetworksResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORKS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListNetworksRequest.page_size], use
    the [next_page_token] as the value
    for the [ListNetworksRequest.page_token] query parameter
    in the next list request. Subsequent list requests will have their own
    [next_page_token] to continue paging through the results.
    """
    @property
    def networks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.vpc.v1.network_pb2.Network]:
        """List of Network resources."""

    def __init__(
        self,
        *,
        networks: collections.abc.Iterable[yandex.cloud.vpc.v1.network_pb2.Network] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["networks", b"networks", "next_page_token", b"next_page_token"]) -> None: ...

global___ListNetworksResponse = ListNetworksResponse

@typing.final
class CreateNetworkRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder for this request to create a network in.
    To get the folder ID, use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    name: builtins.str
    """Name of the network.
    The name must be unique within the folder.
    """
    description: builtins.str
    """Description of the network."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `` key:value `` pairs."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "folder_id", b"folder_id", "labels", b"labels", "name", b"name"]) -> None: ...

global___CreateNetworkRequest = CreateNetworkRequest

@typing.final
class CreateNetworkMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_ID_FIELD_NUMBER: builtins.int
    network_id: builtins.str
    """ID of the Network that is being created."""
    def __init__(
        self,
        *,
        network_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["network_id", b"network_id"]) -> None: ...

global___CreateNetworkMetadata = CreateNetworkMetadata

@typing.final
class UpdateNetworkRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    NETWORK_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    network_id: builtins.str
    """ID of the Network resource to update.
    To get the network ID use a [NetworkService.List] request.
    """
    name: builtins.str
    """Name of the network.
    The name must be unique within the folder.
    """
    description: builtins.str
    """Description of the network."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the Network resource are going to be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `` key:value `` pairs."""

    def __init__(
        self,
        *,
        network_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "labels", b"labels", "name", b"name", "network_id", b"network_id", "update_mask", b"update_mask"]) -> None: ...

global___UpdateNetworkRequest = UpdateNetworkRequest

@typing.final
class UpdateNetworkMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_ID_FIELD_NUMBER: builtins.int
    network_id: builtins.str
    """ID of the Network resource that is being updated."""
    def __init__(
        self,
        *,
        network_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["network_id", b"network_id"]) -> None: ...

global___UpdateNetworkMetadata = UpdateNetworkMetadata

@typing.final
class DeleteNetworkRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_ID_FIELD_NUMBER: builtins.int
    network_id: builtins.str
    """ID of the Network resource to update.
    To get the network ID, use a [NetworkService.List] request.
    """
    def __init__(
        self,
        *,
        network_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["network_id", b"network_id"]) -> None: ...

global___DeleteNetworkRequest = DeleteNetworkRequest

@typing.final
class DeleteNetworkMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_ID_FIELD_NUMBER: builtins.int
    network_id: builtins.str
    """ID of the network that is being deleted."""
    def __init__(
        self,
        *,
        network_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["network_id", b"network_id"]) -> None: ...

global___DeleteNetworkMetadata = DeleteNetworkMetadata

@typing.final
class ListNetworkSubnetsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    network_id: builtins.str
    """ID of the Network resource to list subnets for."""
    page_size: builtins.int
    """The maximum number of results per page that should be returned. If the number of available
    results is larger than [page_size],
    the service returns a [ListNetworkSubnetsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests. Default value: 100.
    """
    page_token: builtins.str
    """Page token. Set [page_token]
    to the [ListNetworkSubnetsResponse.next_page_token]
    returned by a previous list request to get the next page of results.
    """
    def __init__(
        self,
        *,
        network_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["network_id", b"network_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListNetworkSubnetsRequest = ListNetworkSubnetsRequest

@typing.final
class ListNetworkSubnetsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBNETS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListNetworkSubnetsRequest.page_size], use
    the [next_page_token] as the value
    for the [ListNetworkSubnetsRequest.page_token] query parameter
    in the next list request. Subsequent list requests will have their own
    [next_page_token] to continue paging through the results.
    """
    @property
    def subnets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.vpc.v1.subnet_pb2.Subnet]:
        """List of subnets that belong to the network which is specified in the request."""

    def __init__(
        self,
        *,
        subnets: collections.abc.Iterable[yandex.cloud.vpc.v1.subnet_pb2.Subnet] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "subnets", b"subnets"]) -> None: ...

global___ListNetworkSubnetsResponse = ListNetworkSubnetsResponse

@typing.final
class ListNetworkSecurityGroupsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    network_id: builtins.str
    """ID of the Network resource to list security groups for."""
    page_size: builtins.int
    """The maximum number of results per page that should be returned. If the number of available
    results is larger than [page_size],
    the service returns a [ListNetworkSecurityGroupsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests. Default value: 100.
    """
    page_token: builtins.str
    """Page token. Set [page_token]
    to the [ListNetworkSecurityGroupsResponse.next_page_token]
    returned by a previous list request to get the next page of results.
    """
    def __init__(
        self,
        *,
        network_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["network_id", b"network_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListNetworkSecurityGroupsRequest = ListNetworkSecurityGroupsRequest

@typing.final
class ListNetworkSecurityGroupsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListNetworkSecurityGroupsRequest.page_size], use
    the [next_page_token] as the value
    for the [ListNetworkSecurityGroupsRequest.page_token] query parameter
    in the next list request. Subsequent list requests will have their own
    [next_page_token] to continue paging through the results.
    """
    @property
    def security_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.vpc.v1.security_group_pb2.SecurityGroup]:
        """List of security groups that belong to the network which is specified in the request."""

    def __init__(
        self,
        *,
        security_groups: collections.abc.Iterable[yandex.cloud.vpc.v1.security_group_pb2.SecurityGroup] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "security_groups", b"security_groups"]) -> None: ...

global___ListNetworkSecurityGroupsResponse = ListNetworkSecurityGroupsResponse

@typing.final
class ListNetworkRouteTablesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    network_id: builtins.str
    """ID of the Network resource to list route tables for."""
    page_size: builtins.int
    """The maximum number of results per page that should be returned. If the number of available
    results is larger than [page_size],
    the service returns a [ListNetworkRouteTablesResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests. Default value: 100.
    """
    page_token: builtins.str
    """Page token. Set [page_token]
    to the [ListNetworkRouteTablesResponse.next_page_token]
    returned by a previous list request to get the next page of results.
    """
    def __init__(
        self,
        *,
        network_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["network_id", b"network_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListNetworkRouteTablesRequest = ListNetworkRouteTablesRequest

@typing.final
class ListNetworkRouteTablesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROUTE_TABLES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListNetworkRouteTablesRequest.page_size], use
    the [next_page_token] as the value
    for the [ListNetworkRouteTablesRequest.page_token] query parameter
    in the next list request. Subsequent list requests will have their own
    [next_page_token] to continue paging through the results.
    """
    @property
    def route_tables(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.vpc.v1.route_table_pb2.RouteTable]:
        """List of route tables that belong to the network which is specified in the request."""

    def __init__(
        self,
        *,
        route_tables: collections.abc.Iterable[yandex.cloud.vpc.v1.route_table_pb2.RouteTable] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "route_tables", b"route_tables"]) -> None: ...

global___ListNetworkRouteTablesResponse = ListNetworkRouteTablesResponse

@typing.final
class ListNetworkOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    network_id: builtins.str
    """ID of the Network resource to list operations for."""
    page_size: builtins.int
    """The maximum number of results per page that should be returned. If the number of available
    results is larger than [page_size], the service returns a [ListNetworkOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests. Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListNetworkOperationsResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        network_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["network_id", b"network_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListNetworkOperationsRequest = ListNetworkOperationsRequest

@typing.final
class ListNetworkOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListNetworkOperationsRequest.page_size], use the [next_page_token] as the value
    for the [ListNetworkOperationsRequest.page_token] query parameter in the next list request.
    Each subsequent list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified network."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListNetworkOperationsResponse = ListNetworkOperationsResponse

@typing.final
class MoveNetworkRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_ID_FIELD_NUMBER: builtins.int
    DESTINATION_FOLDER_ID_FIELD_NUMBER: builtins.int
    network_id: builtins.str
    """ID of the Network resource to move."""
    destination_folder_id: builtins.str
    """ID of the destination folder."""
    def __init__(
        self,
        *,
        network_id: builtins.str = ...,
        destination_folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["destination_folder_id", b"destination_folder_id", "network_id", b"network_id"]) -> None: ...

global___MoveNetworkRequest = MoveNetworkRequest

@typing.final
class MoveNetworkMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_ID_FIELD_NUMBER: builtins.int
    network_id: builtins.str
    """ID of the network that is being moved."""
    def __init__(
        self,
        *,
        network_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["network_id", b"network_id"]) -> None: ...

global___MoveNetworkMetadata = MoveNetworkMetadata



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/loadtesting/api/v1/common/quantiles.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/loadtesting/api/v1/common/quantiles.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6yandex/cloud/loadtesting/api/v1/common/quantiles.proto\x12&yandex.cloud.loadtesting.api.v1.common\"\x81\x01\n\tQuantiles\x12\x0b\n\x03q50\x18\x01 \x01(\x01\x12\x0b\n\x03q75\x18\x02 \x01(\x01\x12\x0b\n\x03q80\x18\x03 \x01(\x01\x12\x0b\n\x03q85\x18\x04 \x01(\x01\x12\x0b\n\x03q90\x18\x05 \x01(\x01\x12\x0b\n\x03q95\x18\x06 \x01(\x01\x12\x0b\n\x03q98\x18\x07 \x01(\x01\x12\x0b\n\x03q99\x18\x08 \x01(\x01\x12\x0c\n\x04q100\x18\t \x01(\x01*\xf4\x01\n\x0cQuantileType\x12\x1d\n\x19QUANTILE_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10QUANTILE_TYPE_50\x10\x01\x12\x14\n\x10QUANTILE_TYPE_75\x10\x02\x12\x14\n\x10QUANTILE_TYPE_80\x10\x03\x12\x14\n\x10QUANTILE_TYPE_85\x10\x04\x12\x14\n\x10QUANTILE_TYPE_90\x10\x05\x12\x14\n\x10QUANTILE_TYPE_95\x10\x06\x12\x14\n\x10QUANTILE_TYPE_98\x10\x07\x12\x14\n\x10QUANTILE_TYPE_99\x10\x08\x12\x15\n\x11QUANTILE_TYPE_100\x10\tB\x7f\n*yandex.cloud.api.loadtesting.api.v1.commonZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/common;commonb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.api.v1.common.quantiles_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n*yandex.cloud.api.loadtesting.api.v1.commonZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/common;common'
  _globals['_QUANTILETYPE']._serialized_start=231
  _globals['_QUANTILETYPE']._serialized_end=475
  _globals['_QUANTILES']._serialized_start=99
  _globals['_QUANTILES']._serialized_end=228
# @@protoc_insertion_point(module_scope)
